<?php

/**
 * Example file showing Net_CDDB usage
 * 
 * @author Keith Palmer <Keith@UglySlug.com>
 * @category Net
 * @package Net_CDDB
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */

header('Content-type: text/plain');
error_reporting(E_ALL);
set_time_limit(4);

require_once 'Net/CDDB.php';

$params_cddbp = array(
	'host' => 'bsdslug', 
	'persist' => true, 
	);

$cddb_cddbp = new Net_CDDB('cddbp://keithpalmerjr@freedb.org:8880', 'test:///dev/acd0', $params_cddbp);

$params_http = array(
	'host' => 'bsdslug', 
	);

$cddb_http = new Net_CDDB('http://keithpalmerjr@freedb.org:80', 'test:///dev/acd0', $params_http);

print("\n\nHTTP PROTOCOL RESPONSE:\n\n"); flush();
print(Net_CDDB_example($cddb_http));
	
print("\n\nCDDBP PROTOCOL RESPONSE:\n\n"); flush();
print(Net_CDDB_example($cddb_cddbp));

function Net_CDDB_example($cddb)
{
	print("Searching for the CD in the CD-ROM drive:\n");
	$discs = $cddb->searchDatabaseForCD();
	print_r($discs);
	
	print("\n\nDetails for the first CD from the search are: \n");
	$details = $cddb->getDetails($discs[0]);
	print_r($details);
	
	print("\n\nDumping that disc back to a string looks like this: \n");
	print($details->toString());
	
	print("\n\nDoing a test submit of that disc back to the CDDB server: \n");
	$cddb->submitDisc($details, 'keith@uglyslug.com', true);

	print("\n\nThe CDDB music genres are: \n");
	print_r($cddb->getGenres());

	print("\n\nThe details for disk id: 'rock' '7707af0b' are: \n");
	print_r($cddb->getDetailsByDiscId('rock', '7707af0b', false));
	
	print("\n\nThe disc id for this record is: \n");
	$arr_track_offsets = array(
		150, 
		21052, 
		43715, 
		58057,
		71430, 
		92865, 
		117600, 
		131987, 
		150625, 
		163292, 
		181490, 
		195685, 
		210197, 
		233230, 
		249257
		);
	print_r($cddb->calculateDiscId($arr_track_offsets, 3541));
	
	print("\n\nDiscs which match the description of that record are: \n");
	print_r($cddb->searchDatabase($arr_track_offsets, 3541, false));
	
	print("\n\nCDDB server message of the day: \n");
	print($cddb->motd());
	
	print("\n\nCDDB server protocol help: \n");
	print($cddb->help());
	
	print("\n\nCDDB server version is: \n");
	print($cddb->version());
	
	print("\n\nCDDB server statistics look like this: \n");
	print_r($cddb->statistics());
	
	print("\n\nCDDB server site list looks like this: \n");
	print_r($cddb->sites());
	
	print("\n\n");
}

?>